@@ -1,6 +1,6 @@
 import requests as r
 
-def getsvTableAll(access_token,subscription_key,rootUrl,activeOU,siteview,table,pagesize,cursor):
+def getsvTableAll(access_token,subscription_key,rootUrl,activeOU,siteview,table,cursor,pagesize):
     call_headers = {
                 "Content-Type":'application/json',
                 "Authorization":"Bearer %s" %(access_token),
@@ -11,7 +11,7 @@ def getsvTableAll(access_token,subscription_key,rootUrl,activeOU,siteview,table,
     IDWELL = r.get(url=url,headers=call_headers)
     return IDWELL
 
-def getsvTableChanges(access_token,subscription_key,rootUrl,activeOU,siteview,table,pagesize,cursor,date):
+def getsvTableChanges(access_token,subscription_key,rootUrl,activeOU,siteview,table,cursor,pagesize,date):
     call_headers = {
                 "Content-Type":'application/json',
                 "Authorization":"Bearer %s" %(access_token),
@@ -22,7 +22,7 @@ def getsvTableChanges(access_token,subscription_key,rootUrl,activeOU,siteview,ta
     IDWELL = r.get(url=url,headers=call_headers)
     return IDWELL
 
-def getsvTableSingleFilter(access_token,subscription_key,rootUrl,activeOU,siteview,table,pagesize,cursor,filterColumn,filterValue):
+def getsvTableSingleFilter(access_token,subscription_key,rootUrl,activeOU,siteview,table,cursor,pagesize,filterColumn,filterValue):
     call_headers = {
                 "Content-Type":'application/json',
                 "Authorization":"Bearer %s" %(access_token),
@@ -70,3 +70,14 @@ def svReturnBatchStatus(access_token,subscription_key,url,siteview):
     url = F"{url}"
     batch_status = r.get(url=url,headers=call_headers)
     return batch_status
+
+def getsvTableByEntityID(access_token,subscription_key,rootUrl,activeOU,siteview,table,cursor,pagesize,entityId):
+    call_headers = {
+                "Content-Type":'application/json',
+                "Authorization":"Bearer %s" %(access_token),
+                "Ocp-Apim-Subscription-Key":subscription_key,
+                "siteview":siteview
+                }
+    url = F"{rootUrl}/{activeOU}/siteview/data/{table}/entityId/{entityId}?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
+    IDWELL = r.get(url=url,headers=call_headers)
+    return IDWELL
